import { Button, Flex, Input, Space, Table, message } from "antd";
import Column from "antd/es/table/Column";
import { useEffect, useState } from "react";
import axiosInstance from "../../api/axios";
import TeamDeleteButton from "../../components/TeamDeleteButton";

export default function TeamManage() {
  const [teams, setTeams] = useState([]);
  const [data, setData] = useState([]);
  const [searchName, setSearchName] = useState();
  const [editingId, setEditingId] = useState();
  const [editingName, setEditingName] = useState("");
  const [newTeamName, setNewTeamName] = useState();

  const fetchData = async () => {
    const data = await axiosInstance.get("/teams");
    setData(data);
    setTeams(data);
    setSearchName(null);
  };

  useEffect(() => {
    fetchData();
  }, []);

  const handleSearch = (value) => {
    setSearchName(value);
    const filtered = data.filter((item) =>
      item.name.toLowerCase().includes(value.toLowerCase())
    );
    setTeams(filtered);
  };

  const handleDelete = async (record) => {
    await axiosInstance.delete(`/team/${record.id}`);
    message.success("删除成功");
    fetchData();
  };

  const handleEdit = (record) => {
    setEditingId(record.id);
    setEditingName(record.name);
  };

  const handleSave = async (teamId) => {
    if (!editingName.trim()) return message.warning("请输入新名称");
    await axiosInstance.put(`/team/${teamId}`, { name: editingName });
    setEditingId(null);
    message.success("修改成功");
    await fetchData();
  };

  const handleAdd = async () => {
    if (!newTeamName.trim()) {
      message.warning("请输入团队名称");
      return;
    }
    await axiosInstance.post("/team", {
      name: newTeamName,
    });
    message.success("添加成功");
    setNewTeamName(null);
    fetchData();
  };

  return (
    <>
      <Flex justify="space-between">
        <Input.Search
          placeholder="请输入团队名称"
          onSearch={handleSearch}
          onChange={(e) => setSearchName(e.target.value)}
          value={searchName}
          style={{ width: "200px" }}
          className="m-4"
        />
        <Input.Search
          placeholder="请输入新团队名称"
          enterButton="添加团队"
          onSearch={handleAdd}
          value={newTeamName}
          onChange={(e) => setNewTeamName(e.target.value)}
          className="m-4"
          style={{ width: "300px" }}
        />
      </Flex>
      <Table rowKey="id" dataSource={teams}>
        <Column
          title="团队名"
          key="name"
          render={(_, record) => {
            if (record.id === editingId) {
              return (
                <Input
                  value={editingName}
                  onChange={(e) => setEditingName(e.target.value)}
                />
              );
            }
            return record.name;
          }}
        />
        <Column title="下属人数" key="size" dataIndex="size" />
        <Column
          title="操作"
          render={(_, record) => {
            return (
              <Space>
                {record.id === editingId ? (
                  <Space>
                    <Button
                      size="small"
                      type="primary"
                      onClick={() => handleSave(record.id)}
                    >
                      保存
                    </Button>
                    <Button size="small" onClick={() => setEditingId(null)}>
                      取消
                    </Button>
                  </Space>
                ) : (
                  <Button size="small" onClick={() => handleEdit(record)}>
                    编辑
                  </Button>
                )}
                <TeamDeleteButton
                  record={record}
                  onConfirm={() => handleDelete(record)}
                />
              </Space>
            );
          }}
        />
      </Table>
    </>
  );
}
